Tooz
====

.. image:: https://img.shields.io/pypi/v/tooz.svg
    :target: https://pypi.python.org/pypi/tooz/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/tooz.svg
    :target: https://pypi.python.org/pypi/tooz/
    :alt: Downloads

The Tooz project aims at centralizing the most common distributed primitives
like group membership protocol, lock service and leader election by providing
a coordination API helping developers to build distributed applications.

* Free software: Apache license
* Documentation: https://docs.openstack.org/developer/tooz
* Source: http://git.openstack.org/cgit/openstack/tooz
* Bugs: https://bugs.launchpad.net/python-tooz/

Join us
-------

- https://launchpad.net/python-tooz
